@@ -10,6 +10,7 @@ from django.shortcuts import render, get_object_or_404
 
 from invoices.models import SaleItem, ArrivalItem
 from customers.models import Customer
+from customers import forms
 from customers.forms import AddCustomerForm
 
 
@@ -18,10 +19,18 @@ def get_customer_detail(request, customer_id):
 
     customer = get_object_or_404(Customer, id=customer_id)
 
+    form = forms.ReportForm(request.GET)
+
     sale_items = (
         SaleItem
         .objects
-        .filter(invoice__customer=customer)
+        .filter(
+            invoice__customer=customer,
+            invoice__created__date__range=[
+                form.cleaned_data['date_from'],
+                form.cleaned_data['date_to']
+            ]
+        )
         .select_related('invoice')
         .order_by('-invoice__created')
     )
@@ -29,7 +38,13 @@ def get_customer_detail(request, customer_id):
     arrival_items = (
         ArrivalItem
         .objects
-        .filter(invoice__customer=customer)
+        .filter(
+            invoice__customer=customer,
+            invoice__created__date__range=[
+                form.cleaned_data['date_from'],
+                form.cleaned_data['date_to']
+            ]
+        )
         .select_related('invoice')
         .order_by('-invoice__created')
     )
@@ -46,6 +61,7 @@ def get_customer_detail(request, customer_id):
             'total': sum([s.subtotal_with_discount for s in arrival_items]),
             'qty': sum([s.qty for s in arrival_items])
         },
+        'form': form,
         **admin.site.each_context(request)
     })
 
